@@ -43,7 +43,7 @@ use super::super::offset::libc_posix_fadvise;
     target_os = "redox",
 )))]
 use super::super::offset::libc_posix_fallocate;
-use super::super::offset::{libc_fstat, libc_fstatat, libc_lseek, libc_off_t};
+use super::super::offset::{libc_fstat, libc_fstatat, libc_ftruncate, libc_lseek, libc_off_t};
 use super::super::time::Timespec;
 #[cfg(not(any(
     target_os = "dragonfly",
@@ -84,6 +84,8 @@ use crate::ffi::ZStr;
 #[cfg(any(target_os = "ios", target_os = "macos"))]
 use crate::ffi::ZString;
 use crate::io::{self, OwnedFd, SeekFrom};
+#[cfg(not(target_os = "wasi"))]
+use crate::process::{Gid, Uid};
 use core::convert::TryInto;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 use core::mem::size_of;
@@ -108,6 +110,9 @@ pub(crate) fn openat(
     mode: Mode,
 ) -> io::Result<OwnedFd> {
     unsafe {
+        // Pass `mode` as a `c_uint` even if `mode_t` is narrower, since
+        // `libc_openat` is declared as a variadic function and narrrower
+        // arguments are promoted.
         ret_owned_fd(libc_openat(
             borrowed_fd(dirfd),
             c_str(path),
@@ -301,11 +306,14 @@ pub(crate) fn chmodat(dirfd: BorrowedFd<'_>, path: &ZStr, mode: Mode) -> io::Res
 pub(crate) fn chmodat(dirfd: BorrowedFd<'_>, path: &ZStr, mode: Mode) -> io::Result<()> {
     // Note that Linux's `fchmodat` does not have a flags argument.
     unsafe {
+        // Pass `mode` as a `c_uint` even if `mode_t` is narrower, since
+        // `libc_openat` is declared as a variadic function and narrrower
+        // arguments are promoted.
         syscall_ret(c::syscall(
             c::SYS_fchmodat,
             borrowed_fd(dirfd),
             c_str(path),
-            mode.bits(),
+            c::c_uint::from(mode.bits()),
         ))
     }
 }
@@ -329,6 +337,25 @@ pub(crate) fn fclonefileat(
     unsafe { ret(fclonefileat(srcfd, dst_dirfd, c_str(dst), flags.bits())) }
 }
 
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
+pub(crate) fn chownat(
+    dirfd: BorrowedFd<'_>,
+    path: &ZStr,
+    owner: Uid,
+    group: Gid,
+    flags: AtFlags,
+) -> io::Result<()> {
+    unsafe {
+        ret(c::fchownat(
+            borrowed_fd(dirfd),
+            c_str(path),
+            owner.as_raw(),
+            group.as_raw(),
+            flags.bits(),
+        ))
+    }
+}
+
 #[cfg(not(any(
     target_os = "ios",
     target_os = "macos",
@@ -500,7 +527,30 @@ pub(crate) fn fchmod(fd: BorrowedFd<'_>, mode: Mode) -> io::Result<()> {
     // implementations, such as musl, add extra logic to `fchmod` to emulate
     // support for `O_PATH`, which uses `/proc` outside our control and
     // interferes with our own use of `O_PATH`.
-    unsafe { syscall_ret(c::syscall(c::SYS_fchmod, borrowed_fd(fd), mode.bits())) }
+    unsafe {
+        syscall_ret(c::syscall(
+            c::SYS_fchmod,
+            borrowed_fd(fd),
+            c::c_uint::from(mode.bits()),
+        ))
+    }
+}
+
+#[cfg(any(target_os = "android", target_os = "linux"))]
+pub(crate) fn fchown(fd: BorrowedFd<'_>, owner: Uid, group: Gid) -> io::Result<()> {
+    unsafe {
+        syscall_ret(c::syscall(
+            c::SYS_fchown,
+            borrowed_fd(fd),
+            owner.as_raw(),
+            group.as_raw(),
+        ))
+    }
+}
+
+#[cfg(not(any(target_os = "android", target_os = "linux", target_os = "wasi")))]
+pub(crate) fn fchown(fd: BorrowedFd<'_>, owner: Uid, group: Gid) -> io::Result<()> {
+    unsafe { ret(c::fchown(borrowed_fd(fd), owner.as_raw(), group.as_raw())) }
 }
 
 #[cfg(not(target_os = "wasi"))]
@@ -611,21 +661,8 @@ pub(crate) fn fdatasync(fd: BorrowedFd<'_>) -> io::Result<()> {
 }
 
 pub(crate) fn ftruncate(fd: BorrowedFd<'_>, length: u64) -> io::Result<()> {
-    // Use `ftruncate64` when available, in Android 12 and later.
-    #[cfg(all(target_os = "android", target_pointer_width = "32"))]
-    {
-        weak!(fn ftruncate64(c_int, i64) -> c_int);
-
-        unsafe {
-            match ftruncate64.get() {
-                Some(f) => return ret(f(fd, size as i64)),
-                None => {}
-            }
-        }
-    }
-
     let length = length.try_into().map_err(|_overflow_err| io::Error::FBIG)?;
-    unsafe { ret(c::ftruncate(borrowed_fd(fd), length)) }
+    unsafe { ret(libc_ftruncate(borrowed_fd(fd), length)) }
 }
 
 #[cfg(any(target_os = "android", target_os = "linux"))]
