@@ -5,7 +5,9 @@ use bitflags::bitflags;
 use core::marker::PhantomData;
 
 bitflags! {
-    /// `POLL*`
+    /// `POLL*` flags for use with [`poll`].
+    ///
+    /// [`poll`]: rustix::io::poll
     pub struct PollFlags: c::c_short {
         /// `POLLIN`
         const IN = c::POLLIN;
@@ -41,7 +43,10 @@ bitflags! {
     }
 }
 
-/// `struct pollfd`
+/// `struct pollfd`—File descriptor and flags for use with [`poll`].
+///
+/// [`poll`]: rustix::io::poll
+#[doc(alias = "pollfd")]
 #[derive(Clone, Debug)]
 #[repr(transparent)]
 pub struct PollFd<'fd> {
