@@ -2,7 +2,9 @@ use super::super::fd::{AsFd, BorrowedFd};
 use bitflags::bitflags;
 
 bitflags! {
-    /// `POLL*`
+    /// `POLL*` flags for use with [`poll`].
+    ///
+    /// [`poll`]: rustix::io::poll
     pub struct PollFlags: u16 {
         /// `POLLIN`
         const IN = linux_raw_sys::general::POLLIN as u16;
@@ -29,7 +31,10 @@ bitflags! {
     }
 }
 
-/// `struct pollfd`
+/// `struct pollfd`—File descriptor and flags for use with [`poll`].
+///
+/// [`poll`]: rustix::io::poll
+#[doc(alias = "pollfd")]
 #[repr(C)]
 #[derive(Debug, Clone)]
 pub struct PollFd<'fd> {
