@@ -2,7 +2,47 @@
 //! POSIX-like, Unix-like, Linux, and Winsock syscall-like APIs, with
 //! configurable backends.
 //!
-//! The wrappers perform the following tasks:
+//! For example, instead of calling libc directly, using an `unsafe` block,
+//! passing a raw file descriptor, passing a raw pointer, passing a buffer
+//! length, manually checking the return value for errors, and manually
+//! converting the return value to the intended type:
+//!
+//! ```rust
+//! # fn read(sock: std::net::TcpStream, buf: &mut [u8]) -> std::io::Result<()> {
+//! # use std::convert::TryInto;
+//! # use rustix::fd::AsRawFd;
+//! # #[cfg(windows)]
+//! # use winapi::um::winsock2 as libc;
+//! # const MSG_PEEK: i32 = libc::MSG_PEEK;
+//! let nread: usize = unsafe {
+//!     match libc::recv(
+//!         sock.as_raw_fd() as _,
+//!         buf.as_mut_ptr().cast(),
+//!         buf.len().try_into().unwrap_or(i32::MAX as _),
+//!         MSG_PEEK,
+//!     ) {
+//!         -1 => return Err(std::io::Error::last_os_error()),
+//!         nread => nread as usize,
+//!     }
+//! };
+//! # let _ = nread;
+//! # Ok(())
+//! # }
+//! ```
+//!
+//! With rustix you can call a safe function, pass it any type that implements
+//! [`AsFd`], pass it a slice, and get a `Result` carrying the intended type:
+//!
+//! ```rust
+//! # fn read(sock: std::net::TcpStream, buf: &mut [u8]) -> std::io::Result<()> {
+//! # use rustix::net::RecvFlags;
+//! let nread: usize = rustix::net::recv(&sock, buf, RecvFlags::PEEK)?;
+//! # let _ = nread;
+//! # Ok(())
+//! # }
+//! ```
+//!
+//! rustix's APIs perform the following tasks:
 //!  - Error values are translated to [`Result`]s.
 //!  - Buffers are passed as Rust slices.
 //!  - Out-parameters are presented as return values.
@@ -36,7 +76,7 @@
 //! [`std`]: https://doc.rust-lang.org/std/
 //! [`getrandom`]: https://crates.io/crates/getrandom
 //! [`bitflags`]: https://crates.io/crates/bitflags
-//! [`AsFd`]: https://docs.rs/io-lifetimes/latest/io_lifetimes/trait.AsFd.html
+//! [`AsFd`]: https://doc.rust-lang.org/stable/std/os/unix/io/trait.AsFd.html
 //! [`OwnedFd`]: https://docs.rs/io-lifetimes/latest/io_lifetimes/struct.OwnedFd.html
 //! [io-lifetimes crate]: https://crates.io/crates/io-lifetimes
 //! [I/O-safe]: https://github.com/rust-lang/rfcs/blob/master/text/3128-io-safety.md
@@ -46,9 +86,9 @@
 #![deny(missing_docs)]
 #![cfg_attr(linux_raw, deny(unsafe_code))]
 #![cfg_attr(asm, feature(asm))]
-#![cfg_attr(any(rustc_attrs, feature = "rustc-dep-of-std"), feature(rustc_attrs))]
+#![cfg_attr(any(rustc_attrs, not(feature = "std")), feature(rustc_attrs))]
 #![cfg_attr(doc_cfg, feature(doc_cfg))]
-#![cfg_attr(target_os = "wasi", feature(wasi_ext))]
+#![cfg_attr(all(target_os = "wasi", feature = "std"), feature(wasi_ext))]
 #![cfg_attr(all(linux_raw, asm, target_arch = "x86"), feature(naked_functions))]
 #![cfg_attr(io_lifetimes_use_std, feature(io_safety))]
 #![cfg_attr(not(feature = "std"), no_std)]
@@ -67,10 +107,14 @@
 #[cfg(not(feature = "rustc-dep-of-std"))]
 extern crate alloc;
 
-/// Export `*Fd*` types and traits that we use in our public API, so that
-/// our users don't need to do anything special to use the same version.
+/// Export `*Fd*` types and traits that used in rustix's public API.
+///
+/// Users can use this to avoid needing to import anything else to use the same
+/// versions of these types and traits.
 ///
 /// Note that `OwnedFd` lives at [`rustix::io::OwnedFd`].
+///
+/// [`rustix::io::OwnedFd`]: crate::io::OwnedFd
 pub mod fd {
     use super::imp;
     pub use imp::fd::{AsFd, AsRawFd, BorrowedFd, FromRawFd, IntoRawFd, RawFd};
