@@ -18,9 +18,8 @@
 #![allow(unsafe_code)]
 
 use crate::ffi::ZStr;
-use crate::path::Arg;
 use crate::process::Pid;
-use crate::{imp, io};
+use crate::{imp, io, path};
 use alloc::borrow::Cow;
 use alloc::vec::Vec;
 use core::ffi::c_void;
@@ -101,29 +100,60 @@ pub use imp::thread::tls::StartupTlsInfo;
 
 /// `fork()`—Creates a new process by duplicating the calling process.
 ///
-/// On success, the PID of the child process is returned in the parent,
-/// and `Pid::NONE` is returned in the child.
-///
-/// Unlike its libc counterpart,
-/// this function does not call handlers registered with [`pthread_atfork`],
-/// and does not initializes the `pthread` data structures in the child
-/// process.
-///
-/// # Safety
+/// On success, the PID of the child process is returned in the parent, and
+/// `Pid::NONE` is returned in the child.
 ///
 /// If the parent has multiple threads, fork creates a child process containing
 /// a copy of all the memory of all the threads, but with only one actual
-/// thread, so objects in memory such as mutexes may be in unusable states.
+/// thread. Mutexes held on threads other than the one that called `fork` in
+/// the parent will appear in the child as if they are locked indefinitely,
+/// and attempting to lock them may deadlock.
+///
+/// Unlike its libc counterpart, this function does not call handlers
+/// registered with [`pthread_atfork`].
+///
+/// # Safety
+///
+/// This function does not update the threading runtime's data structures in
+/// the child process, so higher-level APIs such as `pthread_self` may return
+/// stale values in the child.
+///
+/// And because it doesn't call handlers registered with `pthread_atfork`,
+/// random number generators such as those in the [rand] crate aren't
+/// reinitialized in the child, so may generate the same values in the child
+/// as in the parent.
 ///
 /// # References
 ///  - [Linux]
 ///
 /// [Linux]: https://man7.org/linux/man-pages/man2/fork.2.html
 /// [`pthread_atfork`]: https://man7.org/linux/man-pages/man3/pthread_atfork.3.html
+/// [rand]: https://crates.io/crates/rand
 pub unsafe fn fork() -> io::Result<Pid> {
     imp::syscalls::fork()
 }
 
+/// Executes the program pointed to by `path`, with the arguments `args`, and
+/// the environment variables `env_vars`.
+///
+/// The first argument, by convention, should be the filename associated with
+/// the file being executed.
+pub fn execve<P: path::Arg, A: path::Arg, E: path::Arg>(
+    path: P,
+    args: &[A],
+    env_vars: &[E],
+) -> io::Result<()> {
+    let arg_zstr: Vec<Cow<'_, ZStr>> = args
+        .iter()
+        .map(path::Arg::as_cow_z_str)
+        .collect::<io::Result<_>>()?;
+    let env_zstr: Vec<Cow<'_, ZStr>> = env_vars
+        .iter()
+        .map(path::Arg::as_cow_z_str)
+        .collect::<io::Result<_>>()?;
+    path.into_with_z_str(|path_zstr| _execve(path_zstr, &arg_zstr, &env_zstr))
+}
+
 fn _execve(path: &ZStr, arg_zstr: &[Cow<'_, ZStr>], env_zstr: &[Cow<'_, ZStr>]) -> io::Result<()> {
     let arg_ptrs: Vec<_> = arg_zstr
         .iter()
@@ -137,20 +167,3 @@ fn _execve(path: &ZStr, arg_zstr: &[Cow<'_, ZStr>], env_zstr: &[Cow<'_, ZStr>])
         .collect();
     unsafe { imp::syscalls::execve(path, &arg_ptrs, &env_ptrs) }
 }
-
-/// Executes the program pointed to by `path`, with the arguments `args`,
-/// and the environment variables `env_vars`.
-///
-/// The first argument, by convention,
-/// should be the filename associated with the file being executed.
-pub fn execve<P: Arg, A: Arg, E: Arg>(path: P, args: &[A], env_vars: &[E]) -> io::Result<()> {
-    let arg_zstr: Vec<Cow<'_, ZStr>> = args
-        .iter()
-        .map(Arg::as_cow_z_str)
-        .collect::<io::Result<_>>()?;
-    let env_zstr: Vec<Cow<'_, ZStr>> = env_vars
-        .iter()
-        .map(Arg::as_cow_z_str)
-        .collect::<io::Result<_>>()?;
-    path.into_with_z_str(|path_zstr| _execve(path_zstr, &arg_zstr, &env_zstr))
-}
